@@ -2,7 +2,9 @@ m <- SDMtune:::bm_maxent
 test <- SDMtune:::t
 
 test_that("The output is correct when test argument is not given", {
-  th <- thresholds(m, type = "cloglog")
+  th <- thresholds(m,
+                   type = "cloglog")
+
   expect_named(th, c("Threshold", "Cloglog value", "Fractional predicted area",
                      "Training omission rate"))
   expect_equal(th$Threshold, c("Minimum training presence",
@@ -12,7 +14,10 @@ test_that("The output is correct when test argument is not given", {
 })
 
 test_that("The output is correct when test argument is given", {
-  th <- thresholds(m, type = "cloglog", test = test)
+  th <- thresholds(m,
+                   type = "cloglog",
+                   test = test)
+
   expect_named(th, c("Threshold", "Cloglog value", "Fractional predicted area",
                      "Training omission rate", "Test omission rate",
                      "P-values"))
